==============================
 Invenio-Communities v1.0.0a7
==============================

Invenio-Communities v1.0.0a7 was released on June 13, 2016.

About
-----

Invenio module that adds support for communities.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-communities==1.0.0a7

Documentation
-------------

   http://pythonhosted.org/invenio-communities/

Happy hacking and thanks for flying Invenio-Communities.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-communities
|   URL: http://invenio-software.org
